@@ -12,7 +12,7 @@ from juriscraper.opinions.united_states.administrative_agency import mspb_p
 
 class Site(mspb_p.Site):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.court_id = self.__module__
         self.type = "Nonprecedential"
         self.display = 60414
