@@ -6,15 +6,16 @@ History:
  - 2014-08-06: Updated by mlr.
 """
 
-from juriscraper.OpinionSite import OpinionSite
-import time
 import datetime
+import time
 from datetime import date
 
+from juriscraper.OpinionSite import OpinionSite
+
 
 class Site(OpinionSite):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.url = "http://www.uscourts.cavc.gov/opinions.php"
         self.court_id = self.__module__
 
@@ -48,31 +49,31 @@ class Site(OpinionSite):
         for t, d in zip(appellants, dates):
             # See: http://en.wikipedia.org/wiki/United_States_Secretary_of_Veterans_Affairs
             if d > datetime.date(2014, 7, 30):
-                case_names.append(t + "v. McDonald")
+                case_names.append(f"{t}v. McDonald")
             elif d > datetime.date(2014, 5, 30):
-                case_names.append(t + " v. Gibson")
+                case_names.append(f"{t} v. Gibson")
             elif d > datetime.date(2009, 1, 20):
-                case_names.append(t + " v. Shinseki")
+                case_names.append(f"{t} v. Shinseki")
             elif d > datetime.date(2007, 12, 20):
-                case_names.append(t + " v. Peake")
+                case_names.append(f"{t} v. Peake")
             elif d > datetime.date(2007, 10, 1):
-                case_names.append(t + " v. Mansfield")
+                case_names.append(f"{t} v. Mansfield")
             elif d > datetime.date(2005, 1, 26):
-                case_names.append(t + " v. Nicholson")
+                case_names.append(f"{t} v. Nicholson")
             elif d > datetime.date(2001, 1, 23):
-                case_names.append(t + " v. Principi")
+                case_names.append(f"{t} v. Principi")
             elif d > datetime.date(2000, 7, 25):
-                case_names.append(t + " v. Gober")
+                case_names.append(f"{t} v. Gober")
             elif d > datetime.date(1998, 1, 2):
-                case_names.append(t + " v. West")
+                case_names.append(f"{t} v. West")
             elif d > datetime.date(1997, 7, 1):
-                case_names.append(t + " v. Gober")
+                case_names.append(f"{t} v. Gober")
             elif d > datetime.date(1993, 1, 22):
-                case_names.append(t + " v. Brown")
+                case_names.append(f"{t} v. Brown")
             elif d > datetime.date(1992, 9, 26):
-                case_names.append(t + " v. Principi")
+                case_names.append(f"{t} v. Principi")
             else:
-                case_names.append(t + " v. Derwinski")
+                case_names.append(f"{t} v. Derwinski")
         return case_names
 
     def _get_precedential_statuses(self):
