@@ -10,7 +10,7 @@ from juriscraper.opinions.united_states.state import delaware
 
 class Site(delaware.Site):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.url = (
             "http://courts.delaware.gov/opinions/List.aspx?ag=Superior%20Court"
         )
