@@ -9,6 +9,6 @@ from juriscraper.opinions.united_states.state import ohio
 
 class Site(ohio.Site):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.court_id = self.__module__
         self.court_index = 6
