@@ -1,13 +1,14 @@
-from juriscraper.opinions.united_states.federal_special import cit
-
 import time
 from datetime import date
+
 from lxml import html
 
+from juriscraper.opinions.united_states.federal_special import cit
+
 
 class Site(cit.Site):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.url = "http://www.cit.uscourts.gov/SlipOpinions/SlipOps-2010.html"
         self.court_id = self.__module__
 
